@@ -1488,7 +1488,7 @@ def test_empty(vfile):
 
 
 def test_read_only():
-    with setup('test.hdf5', 'w') as f:
+    with setup('test.hdf5') as f:
         file = VersionedHDF5File(f)
         timestamp = datetime.datetime.now(datetime.timezone.utc)
         with file.stage_version('version1', timestamp=timestamp) as g:
@@ -1611,7 +1611,7 @@ def test_auto_create_group(vfile):
     assert_equal(vfile['version1']['a']['b']['c'][:], [0, 1, 2])
 
 def test_scalar():
-    with setup('test.hdf5', 'w') as f:
+    with setup('test.hdf5') as f:
         vfile = VersionedHDF5File(f)
         with vfile.stage_version('version1') as g:
             dtype = h5py.special_dtype(vlen=bytes)
@@ -1782,3 +1782,20 @@ def test_datasetwrapper(vfile):
         assert isinstance(sv['bar'].dataset, InMemoryArrayDataset)
         assert sv['bar'].attrs['key'] == 1
         assert sv['bar'].chunks == (2,)
+
+def test_mask_reading(tmp_path):
+    # Reading a virtual dataset with a mask does not work in HDF5, so make
+    # sure it still works for versioned datasets.
+    file_name = os.path.join(tmp_path, 'file.hdf5')
+
+    with h5py.File(file_name, 'w') as f:
+        vf = VersionedHDF5File(f)
+        with vf.stage_version('r0') as sv:
+            sv.create_dataset('bar', data=[1, 2, 3], chunks=(2,))
+
+    with h5py.File(file_name, 'r') as f:
+        vf = VersionedHDF5File(f)
+        sv = vf['r0']
+        mask = np.array([True, True, False], dtype='bool')
+        b = sv['bar'][mask]
+        assert_equal(b, [1, 2])
