@@ -636,12 +636,12 @@ class InMemoryDataset(Dataset):
 
         # === END CODE FROM h5py.Dataset.__getitem__ ===
 
-        idx = ndindex(args).reduce(self.shape)
-
-        arr = np.ndarray(idx.newshape(self.shape), new_dtype, order='C')
+        idx = ndindex(args).expand(self.shape)
 
         if self.id.can_read_direct:
-            return super().__getitem__(args)
+            return super().__getitem__(idx.raw)
+
+        arr = np.ndarray(idx.newshape(self.shape), new_dtype, order='C')
 
         for c in self.chunks.as_subchunks(idx, self.shape):
             if c not in self.id.data_dict:
